@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.7.7"
+    version = "1.7.8"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -160,11 +160,11 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         # 获取预设的阀值
         counts = self.get_option("warning_counts", project)
-        if int(group.status) == 0:
+        if int(group.group.status) == 0:
             data_1 = {
                 "msgtype": "markdown",
                 "markdown": {
-                    "title": group.title,
+                    "title": group.group.title,
                     "text": payload + '\n\n' + '@' + '@'.join(phone)
                 },
                 "at": {
